@@ -12,7 +12,7 @@ from utils.system import get_ip_address
 
 class SqlConnection(object):
 
-    def __init__(self, db_name="production_test"):
+    def __init__(self, db_name="dutdb"):
         self.host = None
         self.port = None
         self.user = None
